@@ -19,6 +19,7 @@ from .keyboard import *
 from .loadso import *
 from .log import *
 from .messagebox import *
+from .metal import *
 from .mouse import *
 from .pixels import *
 from .platform import *
@@ -26,6 +27,7 @@ from .power import *
 from .rect import *
 from .render import *
 from .rwops import *
+from .sensor import *
 from .shape import *
 from .stdinc import *
 from .surface import *
@@ -34,6 +36,8 @@ from .timer import *
 from .touch import *
 from .version import *
 from .video import *
+from .locale import *
+from .misc import *
 
 from .keycode import *
 from .scancode import *
@@ -50,10 +54,13 @@ SDL_INIT_JOYSTICK = 0x00000200
 SDL_INIT_HAPTIC = 0x00001000
 SDL_INIT_GAMECONTROLLER = 0x00002000
 SDL_INIT_EVENTS = 0x00004000
+SDL_INIT_SENSOR = 0x00008000
 SDL_INIT_NOPARACHUTE = 0x00100000
-SDL_INIT_EVERYTHING = (SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO |
-                       SDL_INIT_EVENTS | SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC |
-                       SDL_INIT_GAMECONTROLLER)
+SDL_INIT_EVERYTHING = (
+    SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |
+    SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER |
+    SDL_INIT_SENSOR
+)
 
 SDL_Init = _bind("SDL_Init", [Uint32], _cint)
 SDL_InitSubSystem = _bind("SDL_InitSubSystem", [Uint32], _cint)
@@ -61,5 +68,5 @@ SDL_QuitSubSystem = _bind("SDL_QuitSubSystem", [Uint32])
 SDL_WasInit = _bind("SDL_WasInit", [Uint32], Uint32)
 SDL_Quit = _bind("SDL_Quit")
 
-__version__ = "0.9.5"
-version_info = (0, 9, 5, "")
+__version__ = "0.9.8"
+version_info = (0, 9, 8)
