@@ -1,36 +1,56 @@
 from ctypes import Structure, c_int, c_char_p, c_double, c_void_p, CFUNCTYPE, \
     POINTER
-from .dll import _bind, nullfunc
+from .dll import _bind
 from .endian import SDL_BYTEORDER, SDL_LIL_ENDIAN
 from .stdinc import Uint8, Uint16, Uint32
 from .rwops import SDL_RWops, SDL_RWFromFile
 
-__all__ = ["SDL_AudioFormat", "SDL_AUDIO_MASK_BITSIZE",
-           "SDL_AUDIO_MASK_DATATYPE", "SDL_AUDIO_MASK_ENDIAN",
-           "SDL_AUDIO_MASK_SIGNED", "SDL_AUDIO_BITSIZE", "SDL_AUDIO_ISFLOAT",
-           "SDL_AUDIO_ISBIGENDIAN", "SDL_AUDIO_ISSIGNED", "SDL_AUDIO_ISINT",
-           "SDL_AUDIO_ISLITTLEENDIAN", "SDL_AUDIO_ISUNSIGNED", "AUDIO_U8",
-           "AUDIO_S8", "AUDIO_U16LSB", "AUDIO_S16LSB", "AUDIO_U16MSB",
-           "AUDIO_S16MSB", "AUDIO_U16", "AUDIO_S16", "AUDIO_S32LSB",
-           "AUDIO_S32MSB", "AUDIO_S32", "AUDIO_F32LSB", "AUDIO_S32MSB",
-           "AUDIO_F32", "AUDIO_U16SYS", "AUDIO_S16SYS", "AUDIO_S32SYS", "AUDIO_FORMATS",
-           "AUDIO_F32SYS", "SDL_AUDIO_ALLOW_FREQUENCY_CHANGE",
-           "SDL_AUDIO_ALLOW_FORMAT_CHANGE", "SDL_AUDIO_ALLOW_CHANNELS_CHANGE",
-           "SDL_AUDIO_ALLOW_ANY_CHANGE", "SDL_AudioCallback", "SDL_AudioSpec",
-           "SDL_AudioCVT", "SDL_AudioFilter", "SDL_GetNumAudioDrivers",
-           "SDL_GetAudioDriver", "SDL_AudioInit", "SDL_AudioQuit",
-           "SDL_GetCurrentAudioDriver", "SDL_OpenAudio", "SDL_AudioDeviceID",
-           "SDL_GetNumAudioDevices", "SDL_GetAudioDeviceName",
-           "SDL_OpenAudioDevice", "SDL_AUDIO_STOPPED", "SDL_AUDIO_PLAYING",
-           "SDL_AUDIO_PAUSED", "SDL_AudioStatus", "SDL_GetAudioStatus",
-           "SDL_GetAudioDeviceStatus", "SDL_PauseAudio", "SDL_PauseAudioDevice",
-           "SDL_LoadWAV_RW", "SDL_LoadWAV", "SDL_FreeWAV", "SDL_BuildAudioCVT",
-           "SDL_ConvertAudio", "SDL_MIX_MAXVOLUME", "SDL_MixAudio",
-           "SDL_MixAudioFormat", "SDL_LockAudio", "SDL_LockAudioDevice",
-           "SDL_UnlockAudio", "SDL_UnlockAudioDevice", "SDL_CloseAudio",
-           "SDL_CloseAudioDevice", "SDL_QueueAudio", "SDL_GetQueuedAudioSize",
-           "SDL_ClearQueuedAudio", "SDL_DequeueAudio"
-         ]
+__all__ = [
+    # Structs & Opaque Types
+    "SDL_AudioSpec", "SDL_AudioCVT",
+
+    # Defines
+    "SDL_AudioFormat", "SDL_AUDIO_MASK_BITSIZE", "SDL_AUDIO_MASK_DATATYPE",
+    "SDL_AUDIO_MASK_ENDIAN", "SDL_AUDIO_MASK_SIGNED", "SDL_AUDIO_BITSIZE",
+    "SDL_AUDIO_ISFLOAT",
+    "AUDIO_U8", "AUDIO_S8", "AUDIO_U16LSB", "AUDIO_S16LSB", "AUDIO_U16MSB",
+    "AUDIO_S16MSB", "AUDIO_U16", "AUDIO_S16", "AUDIO_S32LSB", "AUDIO_S32MSB",
+    "AUDIO_S32", "AUDIO_F32LSB", "AUDIO_S32MSB","AUDIO_F32",
+    "AUDIO_U16SYS", "AUDIO_S16SYS", "AUDIO_S32SYS", "AUDIO_F32SYS",
+    "SDL_AUDIO_ALLOW_FREQUENCY_CHANGE", "SDL_AUDIO_ALLOW_FORMAT_CHANGE",
+    "SDL_AUDIO_ALLOW_CHANNELS_CHANGE", "SDL_AUDIO_ALLOW_SAMPLES_CHANGE",
+    "SDL_AUDIO_ALLOW_ANY_CHANGE",
+    "SDL_AUDIOCVT_MAX_FILTERS", "SDL_MIX_MAXVOLUME",
+
+    # Enums
+    "SDL_AudioStatus",
+    "SDL_AUDIO_STOPPED", "SDL_AUDIO_PLAYING", "SDL_AUDIO_PAUSED", 
+
+    # Macro Functions
+    "SDL_AUDIO_ISBIGENDIAN", "SDL_AUDIO_ISSIGNED", "SDL_AUDIO_ISINT",
+    "SDL_AUDIO_ISLITTLEENDIAN", "SDL_AUDIO_ISUNSIGNED", "SDL_LoadWAV",
+
+    # Functions
+    "SDL_GetNumAudioDrivers", "SDL_GetAudioDriver", "SDL_AudioInit",
+    "SDL_AudioQuit", "SDL_GetCurrentAudioDriver", "SDL_OpenAudio",
+    "SDL_AudioDeviceID", "SDL_GetNumAudioDevices", "SDL_GetAudioDeviceName",
+    "SDL_OpenAudioDevice", "SDL_GetAudioStatus", "SDL_GetAudioDeviceStatus",
+    "SDL_PauseAudio", "SDL_PauseAudioDevice", "SDL_LoadWAV_RW", "SDL_FreeWAV",
+    "SDL_BuildAudioCVT", "SDL_ConvertAudio",  "SDL_MixAudio",
+    "SDL_MixAudioFormat", "SDL_LockAudio", "SDL_LockAudioDevice",
+    "SDL_UnlockAudio", "SDL_UnlockAudioDevice", "SDL_CloseAudio",
+    "SDL_CloseAudioDevice", "SDL_QueueAudio", "SDL_GetQueuedAudioSize",
+    "SDL_ClearQueuedAudio", "SDL_DequeueAudio", "SDL_AudioStream",
+    "SDL_NewAudioStream", "SDL_AudioStreamPut", "SDL_AudioStreamGet",
+    "SDL_AudioStreamAvailable", "SDL_AudioStreamClear",
+    "SDL_FreeAudioStream",
+
+    # Callback Functions
+    "SDL_AudioCallback", "SDL_AudioFilter",
+
+    # Convenience Variables
+    "AUDIO_FORMATS"
+]
 
 SDL_AudioFormat = Uint16
 
@@ -84,9 +104,11 @@ else:
 SDL_AUDIO_ALLOW_FREQUENCY_CHANGE = 0x00000001
 SDL_AUDIO_ALLOW_FORMAT_CHANGE = 0x00000002
 SDL_AUDIO_ALLOW_CHANNELS_CHANGE = 0x00000004
-SDL_AUDIO_ALLOW_ANY_CHANGE = (SDL_AUDIO_ALLOW_FREQUENCY_CHANGE |
-                              SDL_AUDIO_ALLOW_FORMAT_CHANGE |
-                              SDL_AUDIO_ALLOW_CHANNELS_CHANGE)
+SDL_AUDIO_ALLOW_SAMPLES_CHANGE = 0x00000008
+SDL_AUDIO_ALLOW_ANY_CHANGE = (
+    SDL_AUDIO_ALLOW_FREQUENCY_CHANGE | SDL_AUDIO_ALLOW_FORMAT_CHANGE |
+    SDL_AUDIO_ALLOW_CHANNELS_CHANGE | SDL_AUDIO_ALLOW_SAMPLES_CHANGE
+)
 
 SDL_AudioCallback = CFUNCTYPE(None, c_void_p, POINTER(Uint8), c_int)
 
@@ -111,6 +133,8 @@ class SDL_AudioSpec(Structure):
         self.callback = callback
         self.userdata = userdata
 
+SDL_AUDIOCVT_MAX_FILTERS = 9
+
 class SDL_AudioCVT(Structure):
     pass
 
@@ -124,9 +148,12 @@ SDL_AudioCVT._fields_ = [("needed", c_int),
                          ("len_cvt", c_int),
                          ("len_mult", c_int),
                          ("len_ratio", c_double),
-                         ("filters", (SDL_AudioFilter * 10)),
+                         ("filters", (SDL_AudioFilter * (SDL_AUDIOCVT_MAX_FILTERS+1))),
                          ("filter_index", c_int)
-                         ]
+                        ]
+
+class SDL_AudioStream(c_void_p):
+    pass
 
 SDL_GetNumAudioDrivers = _bind("SDL_GetNumAudioDrivers", None, c_int)
 SDL_GetAudioDriver = _bind("SDL_GetAudioDriver", [c_int], c_char_p)
@@ -160,8 +187,13 @@ SDL_UnlockAudio = _bind("SDL_UnlockAudio")
 SDL_UnlockAudioDevice = _bind("SDL_UnlockAudioDevice", [SDL_AudioDeviceID])
 SDL_CloseAudio = _bind("SDL_CloseAudio")
 SDL_CloseAudioDevice = _bind("SDL_CloseAudioDevice", [SDL_AudioDeviceID])
-SDL_QueueAudio = _bind("SDL_QueueAudio", [SDL_AudioDeviceID, c_void_p, Uint32], c_int, nullfunc)
-SDL_DequeueAudio = _bind("SDL_DequeueAudio", [SDL_AudioDeviceID, c_void_p, Uint32], Uint32, nullfunc)
-SDL_GetQueuedAudioSize = _bind("SDL_GetQueuedAudioSize", [SDL_AudioDeviceID], Uint32, nullfunc)
-SDL_ClearQueuedAudio = _bind("SDL_ClearQueuedAudio", [SDL_AudioDeviceID], optfunc=nullfunc)
-
+SDL_QueueAudio = _bind("SDL_QueueAudio", [SDL_AudioDeviceID, c_void_p, Uint32], c_int)
+SDL_DequeueAudio = _bind("SDL_DequeueAudio", [SDL_AudioDeviceID, c_void_p, Uint32], Uint32)
+SDL_GetQueuedAudioSize = _bind("SDL_GetQueuedAudioSize", [SDL_AudioDeviceID], Uint32)
+SDL_ClearQueuedAudio = _bind("SDL_ClearQueuedAudio", [SDL_AudioDeviceID])
+SDL_NewAudioStream = _bind("SDL_NewAudioStream", [SDL_AudioFormat, Uint8, c_int, SDL_AudioFormat, Uint8, c_int], POINTER(SDL_AudioStream), added='2.0.7')
+SDL_AudioStreamPut = _bind("SDL_AudioStreamPut", [POINTER(SDL_AudioStream), c_void_p, c_int], c_int, added='2.0.7')
+SDL_AudioStreamGet = _bind("SDL_AudioStreamGet", [POINTER(SDL_AudioStream), c_void_p, c_int], c_int, added='2.0.7')
+SDL_AudioStreamAvailable = _bind("SDL_AudioStreamAvailable", [POINTER(SDL_AudioStream)], c_int, added='2.0.7')
+SDL_AudioStreamClear = _bind("SDL_AudioStreamClear", [POINTER(SDL_AudioStream)], added='2.0.7')
+SDL_FreeAudioStream = _bind("SDL_FreeAudioStream", [POINTER(SDL_AudioStream)], added='2.0.7')
