@@ -1,12 +1,13 @@
 import os
 import sys
 import array
-import unittest
+import pytest
 from ctypes import c_int, byref, cast, POINTER, c_void_p
-from ..ext import CTypesView
-from .. import SDL_Init, SDL_Quit, SDL_INIT_EVERYTHING
-from ..stdinc import Uint8, Uint32, SDL_TRUE, SDL_FALSE
-from .. import blendmode, pixels, rect, surface, rwops, error
+import sdl2
+from sdl2.ext import CTypesView
+from sdl2 import SDL_Init, SDL_Quit, SDL_INIT_EVERYTHING
+from sdl2.stdinc import Uint8, Uint32, SDL_TRUE, SDL_FALSE
+from sdl2 import blendmode, pixels, rect, surface, rwops, error
 
 to_ctypes = lambda seq, dtype: (dtype * len(seq))(*seq)
 
@@ -45,21 +46,23 @@ blitpositions = (
 
 
 # TODO: mostly covers positive tests right now - fix this!
-class SDLSurfaceTest(unittest.TestCase):
+class TestSDLSurface(object):
     __tags__ = ["sdl"]
 
-    def setUp(self):
-        self.testfile = os.path.join(os.path.dirname
+    @classmethod
+    def setup_class(cls):
+        cls.testfile = os.path.join(os.path.dirname
                                      (os.path.abspath(__file__)),
                                      "resources", "surfacetest.bmp")
         SDL_Init(SDL_INIT_EVERYTHING)
 
-    def tearDown(self):
+    @classmethod
+    def teardown_class(cls):
         SDL_Quit()
 
     def test_SDL_Surface(self):
         sf = surface.SDL_Surface()
-        self.assertIsInstance(sf, surface.SDL_Surface)
+        assert isinstance(sf, surface.SDL_Surface)
         # TODO: property checks
 
     def test_SDL_ConvertPixels(self):
@@ -76,30 +79,40 @@ class SDLSurfaceTest(unittest.TestCase):
             dstp = cast(dst, POINTER(Uint8))
             ret = surface.SDL_ConvertPixels(16, 16, fmt, srcp, 16 * bytecount,
                                             fmt, dstp, 16 * bytecount)
-            self.assertEqual(ret, 0)
+            assert ret == 0
             for index, val in enumerate(dst):
-                self.assertEqual(val, src.view[index])
+                assert val == src.view[index]
 
     def test_SDL_ConvertSurface(self):
+        tenbit = [pixels.SDL_PACKEDLAYOUT_2101010, pixels.SDL_PACKEDLAYOUT_1010102]
         for idx in pixels.ALL_PIXELFORMATS:
-            if pixels.SDL_ISPIXELFORMAT_FOURCC(idx):
-                continue
             pfmt = pixels.SDL_AllocFormat(idx)
             for fmt in pixels.ALL_PIXELFORMATS:
-                if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt):
+                idx_name = pixels.SDL_GetPixelFormatName(idx).decode('utf-8') # for debug
+                fmt_name = pixels.SDL_GetPixelFormatName(fmt).decode('utf-8') # for debug
+                # SDL2 doesn't support converting fancier formats (e.g YUV, 10bit)
+                if pixels.SDL_ISPIXELFORMAT_FOURCC(idx) or pixels.SDL_PIXELLAYOUT(idx) in tenbit:
+                    continue
+                if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt) or pixels.SDL_PIXELLAYOUT(fmt) in tenbit:
+                    continue
+                # SDL2 doesn't support converting to formats w/ less than 8 bpp
+                if pixels.SDL_BITSPERPIXEL(idx) < 8:
+                    continue
+                # SDL2 doesn't support converting from indexed formats w/ 4 bpp
+                if pixels.SDL_PIXELTYPE(fmt) == pixels.SDL_PIXELTYPE_INDEX4:
                     continue
                 bpp = c_int()
                 rmask, gmask, bmask, amask = Uint32(), Uint32(), Uint32(), Uint32()
                 ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                         byref(rmask), byref(gmask),
                                                         byref(bmask), byref(amask))
-                self.assertEqual(ret, SDL_TRUE)
+                assert ret == SDL_TRUE
                 sf = surface.SDL_CreateRGBSurface(0, 10, 20, bpp, rmask, gmask,
                                                   bmask, amask)
-                self.assertIsInstance(sf.contents, surface.SDL_Surface)
+                assert isinstance(sf.contents, surface.SDL_Surface)
                 csf = surface.SDL_ConvertSurface(sf, pfmt, 0)
-                self.assertTrue(csf, error.SDL_GetError())
-                self.assertIsInstance(csf.contents, surface.SDL_Surface)
+                assert csf, error.SDL_GetError()
+                assert isinstance(csf.contents, surface.SDL_Surface)
                 surface.SDL_FreeSurface(sf)
                 surface.SDL_FreeSurface(csf)
             pixels.SDL_FreeFormat(pfmt)
@@ -124,24 +137,32 @@ class SDLSurfaceTest(unittest.TestCase):
         #######################################################################
 
     def test_SDL_ConvertSurfaceFormat(self):
+        tenbit = [pixels.SDL_PACKEDLAYOUT_2101010, pixels.SDL_PACKEDLAYOUT_1010102]
         for pfmt in pixels.ALL_PIXELFORMATS:
-            if pixels.SDL_ISPIXELFORMAT_FOURCC(pfmt):
-                continue
             for fmt in pixels.ALL_PIXELFORMATS:
-                if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt):
+                # SDL2 doesn't support converting fancier formats (e.g YUV, 10bit)
+                if pixels.SDL_ISPIXELFORMAT_FOURCC(pfmt) or pixels.SDL_PIXELLAYOUT(pfmt) in tenbit:
+                    continue
+                if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt) or pixels.SDL_PIXELLAYOUT(fmt) in tenbit:
+                    continue
+                # SDL2 doesn't support converting to formats w/ less than 8 bpp
+                if pixels.SDL_BITSPERPIXEL(pfmt) < 8:
+                    continue
+                # SDL2 doesn't support converting from indexed formats w/ 4 bpp
+                if pixels.SDL_PIXELTYPE(fmt) == pixels.SDL_PIXELTYPE_INDEX4:
                     continue
                 bpp = c_int()
                 rmask, gmask, bmask, amask = Uint32(), Uint32(), Uint32(), Uint32()
                 ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                         byref(rmask), byref(gmask),
                                                         byref(bmask), byref(amask))
-                self.assertEqual(ret, SDL_TRUE)
+                assert ret == SDL_TRUE
                 sf = surface.SDL_CreateRGBSurface(0, 10, 20, bpp, rmask, gmask,
                                                   bmask, amask)
-                self.assertIsInstance(sf.contents, surface.SDL_Surface)
+                assert isinstance(sf.contents, surface.SDL_Surface)
                 csf = surface.SDL_ConvertSurfaceFormat(sf, pfmt, 0)
-                self.assertTrue(csf, error.SDL_GetError())
-                self.assertIsInstance(csf.contents, surface.SDL_Surface)
+                assert csf, error.SDL_GetError()
+                assert isinstance(csf.contents, surface.SDL_Surface)
                 surface.SDL_FreeSurface(sf)
                 surface.SDL_FreeSurface(csf)
 
@@ -150,7 +171,7 @@ class SDLSurfaceTest(unittest.TestCase):
             for h in range(1, 100, 5):
                 for bpp in alldepths:
                     sf = surface.SDL_CreateRGBSurface(0, w, h, bpp, 0, 0, 0, 0)
-                    self.assertIsInstance(sf.contents, surface.SDL_Surface)
+                    assert isinstance(sf.contents, surface.SDL_Surface)
                     surface.SDL_FreeSurface(sf)
 
         bpp = c_int()
@@ -165,10 +186,10 @@ class SDLSurfaceTest(unittest.TestCase):
                                                             byref(gmask),
                                                             byref(bmask),
                                                             byref(amask))
-                    self.assertEqual(ret, SDL_TRUE)
+                    assert ret == SDL_TRUE
                     sf = surface.SDL_CreateRGBSurface(0, 10, 20, bpp, rmask,
                                                       gmask, bmask, amask)
-                    self.assertIsInstance(sf.contents, surface.SDL_Surface)
+                    assert isinstance(sf.contents, surface.SDL_Surface)
                     surface.SDL_FreeSurface(sf)
 
         # Broken ones
@@ -196,6 +217,31 @@ class SDLSurfaceTest(unittest.TestCase):
         #self.assertRaises(sdl.SDLError, surface.create_rgb_surface, 1, 1, 32,
         #                  0xf0, 0x0f, 0x01, 0x02)
 
+    def test_SDL_CreateRGBSurfaceWithFormat(self):
+        for w in range(1, 100, 5):
+            for h in range(1, 100, 5):
+                for bpp in alldepths:
+                    for fmt in pixels.ALL_PIXELFORMATS:
+                        if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt):
+                            continue
+                        sf = surface.SDL_CreateRGBSurfaceWithFormat(0, w, h,
+                                                                    bpp, fmt)
+                        assert isinstance(sf.contents, surface.SDL_Surface)
+                        surface.SDL_FreeSurface(sf)
+
+    def test_SDL_CreateRGBSurfaceWithFormatFrom(self):
+        for buf, bpp, pitch, masks, fmt in rgba_pixelations_16x16:
+            if bpp == 32:
+                arflag = "I"
+            elif bpp == 16:
+                arflag = "H"
+            bytebuf = CTypesView(array.array(arflag, buf))
+            bufptr = cast(bytebuf.to_bytes(), POINTER(Uint8))
+            sf = surface.SDL_CreateRGBSurfaceWithFormatFrom(bufptr, 16, 16,
+                    bpp, pitch, fmt)
+            assert isinstance(sf.contents, surface.SDL_Surface)
+            surface.SDL_FreeSurface(sf)
+
     def test_SDL_CreateRGBSurfaceFrom(self):
         for buf, bpp, pitch, masks, fmt in rgba_pixelations_16x16:
             if bpp == 32:
@@ -207,7 +253,7 @@ class SDLSurfaceTest(unittest.TestCase):
             sf = surface.SDL_CreateRGBSurfaceFrom(bufptr, 16, 16, bpp,
                                                   pitch, masks[0], masks[1],
                                                   masks[2], masks[3])
-            self.assertIsInstance(sf.contents, surface.SDL_Surface)
+            assert isinstance(sf.contents, surface.SDL_Surface)
             surface.SDL_FreeSurface(sf)
 
     def test_SDL_FillRect(self):
@@ -231,7 +277,7 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             for w in range(1, 100, 5):
                 for h in range(1, 100, 5):
                     sf = surface.SDL_CreateRGBSurface(0, w, h, bpp, rmask,
@@ -239,7 +285,7 @@ class SDLSurfaceTest(unittest.TestCase):
                     for r in rectlist:
                         # TODO: check for changed pixels
                         ret = surface.SDL_FillRect(sf, r, 0xff00ff00)
-                        self.assertEqual(ret, 0)
+                        assert ret == 0
                     surface.SDL_FreeSurface(sf)
 
     def test_SDL_FillRects(self):
@@ -261,7 +307,7 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             for w in range(1, 100, 5):
                 for h in range(1, 100, 5):
                     sf = surface.SDL_CreateRGBSurface(0, w, h, bpp, rmask,
@@ -291,7 +337,7 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 5, 5, bpp, rmask, gmask,
                                               bmask, amask)
             surface.SDL_FreeSurface(sf)
@@ -311,17 +357,25 @@ class SDLSurfaceTest(unittest.TestCase):
 
         clip = rect.SDL_Rect()
         sf = surface.SDL_CreateRGBSurface(0, 15, 15, 32, 0, 0, 0, 0)
-        self.assertIsInstance(sf.contents, surface.SDL_Surface)
+        assert isinstance(sf.contents, surface.SDL_Surface)
         surface.SDL_GetClipRect(sf, byref(clip))
-        self.assertEqual(clip, rect.SDL_Rect(0, 0, 15, 15))
+        assert clip == rect.SDL_Rect(0, 0, 15, 15)
 
         for r, clipsetval, cmpval in rectlist:
             retval = surface.SDL_SetClipRect(sf, r)
             surface.SDL_GetClipRect(sf, byref(clip))
-            self.assertEqual(retval, clipsetval,
-                "retval: Could not set clip rect %s" % r)
-            self.assertEqual(clip == r, cmpval,
-                "clip: Could not set clip rect %s" % r)
+            err = "Could not set clip rect %s" % r
+            assert retval == clipsetval, "retval: " + err
+            assert (clip == r) == cmpval, "clip: " + err
+        surface.SDL_FreeSurface(sf)
+
+    @pytest.mark.skipif(sdl2.dll.version < 2009, reason="not available")
+    def test_SDL_HasColorKey(self):
+        sf = surface.SDL_CreateRGBSurface(0, 10, 10, 32, 0, 0, 0, 0)
+        assert surface.SDL_HasColorKey(sf) == SDL_FALSE
+        key = pixels.SDL_MapRGB(sf.contents.format, 255, 255, 255)
+        surface.SDL_SetColorKey(sf, 1, key)
+        assert surface.SDL_HasColorKey(sf) == SDL_TRUE
         surface.SDL_FreeSurface(sf)
 
     def test_SDL_GetSetColorKey(self):
@@ -339,11 +393,11 @@ class SDLSurfaceTest(unittest.TestCase):
             if pixels.SDL_ISPIXELFORMAT_FOURCC(fmt):
                 continue
             pformat = pixels.SDL_AllocFormat(fmt)
-            self.assertIsInstance(pformat.contents, pixels.SDL_PixelFormat)
+            assert isinstance(pformat.contents, pixels.SDL_PixelFormat)
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 10, 10, bpp, rmask, gmask,
                                               bmask, amask)
             for r, g, b in colorkeys:
@@ -351,9 +405,10 @@ class SDLSurfaceTest(unittest.TestCase):
                 surface.SDL_SetColorKey(sf, 1, key)
                 skey = Uint32()
                 ret = surface.SDL_GetColorKey(sf, byref(skey))
-                self.assertEqual(ret, 0)
-                self.assertEqual(skey.value, key,
-                    "Could not set color key (%d, %d, %d)" % (r, g, b))
+                errmsg = "Could not set color key (%d, %d, %d)" % (r, g, b)
+                assert ret == 0
+                assert skey.value == key, errmsg
+                    
             pixels.SDL_FreeFormat(pformat)
             surface.SDL_FreeSurface(sf)
 
@@ -366,19 +421,19 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 10, 10, bpp, rmask, gmask,
                                               bmask, amask)
             salpha = Uint8()
             ret = surface.SDL_GetSurfaceAlphaMod(sf, byref(salpha))
-            self.assertEqual(ret, 0)
-            self.assertEqual(salpha.value, 255)
+            assert ret == 0
+            assert salpha.value == 255
             for alpha in range(0, 255):
                 ret = surface.SDL_SetSurfaceAlphaMod(sf, alpha)
-                self.assertEqual(ret, 0)
+                assert ret == 0
                 ret = surface.SDL_GetSurfaceAlphaMod(sf, byref(salpha))
-                self.assertEqual(ret, 0)
-                self.assertEqual(salpha.value, alpha)
+                assert ret == 0
+                assert salpha.value == alpha
             surface.SDL_FreeSurface(sf)
 
     def test_SDL_GetSetSurfaceBlendMode(self):
@@ -395,15 +450,15 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 10, 10, bpp, rmask, gmask,
                                               bmask, amask)
             for mode in modes:
                 smode = blendmode.SDL_BlendMode()
                 ret = surface.SDL_SetSurfaceBlendMode(sf, mode)
-                self.assertEqual(ret, 0)
+                assert ret == 0
                 surface.SDL_GetSurfaceBlendMode(sf, byref(smode))
-                self.assertEqual(smode.value, mode)
+                assert smode.value == mode
             surface.SDL_FreeSurface(sf)
 
     def test_SDL_GetSetSurfaceColorMod(self):
@@ -423,7 +478,7 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 10, 10, bpp, rmask, gmask,
                                               bmask, amask)
             for r, g, b in colormods:
@@ -431,8 +486,8 @@ class SDLSurfaceTest(unittest.TestCase):
                 surface.SDL_SetSurfaceColorMod(sf, r, g, b)
                 ret = surface.SDL_GetSurfaceColorMod(sf, byref(sr), byref(sg),
                                                      byref(sb))
-                self.assertEqual(ret, 0)
-                self.assertEqual((sr.value, sg.value, sb.value), (r, g, b))
+                assert ret == 0
+                assert (sr.value, sg.value, sb.value) == (r, g, b)
             surface.SDL_FreeSurface(sf)
 
     def test_SDL_LockUnlockMUSTLOCKSurface(self):
@@ -444,24 +499,24 @@ class SDLSurfaceTest(unittest.TestCase):
             ret = pixels.SDL_PixelFormatEnumToMasks(fmt, byref(bpp),
                                                     byref(rmask), byref(gmask),
                                                     byref(bmask), byref(amask))
-            self.assertEqual(ret, SDL_TRUE)
+            assert ret == SDL_TRUE
             sf = surface.SDL_CreateRGBSurface(0, 10, 10, bpp, rmask, gmask,
                                               bmask, amask)
             # TODO: locking seems to be only necessary for RLE surfaces...
             if surface.SDL_MUSTLOCK(sf.contents):
-                self.assertFalse(sf.contents.locked)
+                assert not sf.contents.locked
                 surface.SDL_LockSurface(sf)
-                self.assertTrue(sf.contents.locked)
+                assert sf.contents.locked
                 surface.SDL_LockSurface(sf)
-                self.assertTrue(sf.contents.locked)
+                assert sf.contents.locked
                 surface.SDL_LockSurface(sf)
-                self.assertTrue(sf.contents.locked)
+                assert sf.contents.locked
                 surface.SDL_LockSurface(sf)
-                self.assertTrue(sf.contents.locked)
+                assert sf.contents.locked
                 surface.SDL_LockSurface(sf)
-                self.assertTrue(sf.contents.locked)
+                assert sf.contents.locked
                 surface.SDL_UnlockSurface(sf)
-                self.assertFalse(sf.contents.locked)
+                assert not sf.contents.locked
             surface.SDL_FreeSurface(sf)
 
     def test_SDL_LowerBlit(self):
@@ -491,23 +546,22 @@ class SDLSurfaceTest(unittest.TestCase):
                 iview = pbuf.to_uint32()
                 pw = drect.x + drect.w
                 ph = drect.y + drect.h
+                e = "color mismatch at %d,%d for %s: %d != %d"
                 for y in range(dest.contents.h):
                     for x in range(dest.contents.w):
                         col = iview[y * rowlen + x]
-                        if y >= drect.y and y < ph and \
-                                x >= drect.x and x < pw:
-                            self.assertEqual(col, 0xFFFFFFFF, msg="""color
- mismatch at %d,%d for %s: %d != %d""" % (y, x, pos, col, 0xFFFFFFFF))
+                        if y >= drect.y and y < ph and x >= drect.x and x < pw:
+                            assert col == 0xFFFFFFFF, \
+                                   e % (y, x, pos, col, 0xFFFFFFFF)
                         else:
-                            self.assertEqual(col, 0x0, msg="""color mismatch
- at %d,%d for %s: %d != %d""" % (y, x, pos, col, 0x0))
+                            assert col == 0x0, e % (y, x, pos, col, 0x0)
 
         while len(sources) > 0:
             sf = sources.pop()
             surface.SDL_FreeSurface(sf)
         surface.SDL_FreeSurface(dest)
 
-    @unittest.skip("not implemented")
+    @pytest.mark.skip("not implemented")
     def test_SDL_LowerBlitScaled(self):
         pass
 
@@ -538,16 +592,15 @@ class SDLSurfaceTest(unittest.TestCase):
                 iview = pbuf.to_uint32()
                 pw = drect.x + drect.w
                 ph = drect.y + drect.h
+                e = "color mismatch at %d,%d for %s: %d != %d"
                 for y in range(dest.contents.h):
                     for x in range(dest.contents.w):
                         col = iview[y * rowlen + x]
-                        if y >= drect.y and y < ph and \
-                                x >= drect.x and x < pw:
-                            self.assertEqual(col, 0xFFFFFFFF, msg="""color
- mismatch at %d,%d for %s: %d != %d""" % (x, y, pos, col, 0xFFFFFFFF))
+                        if y >= drect.y and y < ph and x >= drect.x and x < pw:
+                            assert col == 0xFFFFFFFF, \
+                                   e % (x, y, pos, col, 0xFFFFFFFF)
                         else:
-                            self.assertEqual(col, 0x0, msg="""color mismatch
- at %d,%d for %s: %d != %d""" % (x, y, pos, col, 0x0))
+                            assert col == 0x0, e % (x, y, pos, col, 0x0)
 
         while len(sources) > 0:
             sf = sources.pop()
@@ -581,27 +634,26 @@ class SDLSurfaceTest(unittest.TestCase):
                 iview = pbuf.to_uint32()
                 pw = drect.x + drect.w
                 ph = drect.y + drect.h
+                e = "color mismatch at %d,%d for %s: %d != %d"
                 for y in range(dest.contents.h):
                     for x in range(dest.contents.w):
                         col = iview[y * rowlen + x]
-                        if y >= drect.y and y < ph and \
-                                x >= drect.x and x < pw:
-                            self.assertEqual(col, 0xFFFFFFFF, msg="""color
- mismatch at %d,%d for %s: %d != %d""" % (y, x, pos, col, 0xFFFFFFFF))
+                        if y >= drect.y and y < ph and x >= drect.x and x < pw:
+                            assert col == 0xFFFFFFFF, \
+                                   e % (y, x, pos, col, 0xFFFFFFFF)
                         else:
-                            self.assertEqual(col, 0x0, msg="""color mismatch
- at %d,%d for %s: %d != %d""" % (y, x, pos, col, 0x0))
+                            assert col == 0x0, e % (y, x, pos, col, 0x0)
 
         while len(sources) > 0:
             sf = sources.pop()
             surface.SDL_FreeSurface(sf)
         surface.SDL_FreeSurface(dest)
 
-    @unittest.skip("not implemented")
+    @pytest.mark.skip("not implemented")
     def test_SDL_UpperBlitScaled(self):
         pass
 
-    @unittest.skip("not implemented")
+    @pytest.mark.skip("not implemented")
     def test_SDL_SoftStretch(self):
         pass
 
@@ -610,56 +662,69 @@ class SDLSurfaceTest(unittest.TestCase):
         palette = pixels.SDL_AllocPalette(1 << 16)
         sf = surface.SDL_CreateRGBSurface(0, 10, 10, 16, 0, 0, 0, 0)
 
-#        self.assertRaises((AttributeError, TypeError),
-#                          surface.set_surface_palette, None, None)
-#        self.assertRaises((AttributeError, TypeError),
-#                          surface.set_surface_palette, None, palette)
-        self.assertFalse(sf.contents.format.contents.palette)
+        assert not sf.contents.format.contents.palette
         surface.SDL_SetSurfacePalette(sf, palette)
-        self.assertIsNotNone(sf.contents.format.contents.palette.contents)
-#        self.assertRaises(sdl.SDLError, surface.set_surface_palette, sf,
-#                          invpalette)
-        self.assertIsNotNone(sf.contents.format.contents.palette.contents)
+        assert sf.contents.format.contents.palette.contents is not None
+        assert sf.contents.format.contents.palette.contents is not None
         surface.SDL_SetSurfacePalette(sf, None)
-        self.assertFalse(sf.contents.format.contents.palette)
+        assert not sf.contents.format.contents.palette
 
         surface.SDL_FreeSurface(sf)
         pixels.SDL_FreePalette(invpalette)
         pixels.SDL_FreePalette(palette)
 
-    @unittest.skip("not implemented")
     def test_SDL_SetSurfaceRLE(self):
-        pass
+        masks = (0xFF000000, 0x00FF0000, 0x0000FF00, 0x00000000)
+        tst = surface.SDL_CreateRGBSurface(
+            0, 16, 16, 32, masks[0], masks[1], masks[2], masks[3]
+        )
+        assert isinstance(tst.contents, surface.SDL_Surface)
+        # Test for success when setting RLE after locking
+        surface.SDL_LockSurface(tst)
+        ret = surface.SDL_SetSurfaceRLE(tst, 1)
+        assert ret == 0
+        surface.SDL_FreeSurface(tst)
+
+    @pytest.mark.skipif(sdl2.dll.version < 2014, reason="not available")
+    def test_SDL_HasSurfaceRLE(self):
+        masks = (0xFF000000, 0x00FF0000, 0x0000FF00, 0x00000000)
+        tst = surface.SDL_CreateRGBSurface(
+            0, 16, 16, 32, masks[0], masks[1], masks[2], masks[3]
+        )
+        assert isinstance(tst.contents, surface.SDL_Surface)
+        # Test for success before and after setting RLE
+        assert surface.SDL_HasSurfaceRLE(tst) == SDL_FALSE
+        surface.SDL_LockSurface(tst)
+        ret = surface.SDL_SetSurfaceRLE(tst, 1)
+        assert ret == 0
+        assert surface.SDL_HasSurfaceRLE(tst) == SDL_TRUE
+        surface.SDL_FreeSurface(tst)
 
     def test_SDL_LoadBMP_RW(self):
         fp = open(self.testfile, "rb")
         imgrw = rwops.rw_from_object(fp)
         imgsurface = surface.SDL_LoadBMP_RW(imgrw, 0)
-        self.assertIsInstance(imgsurface.contents, surface.SDL_Surface)
+        assert isinstance(imgsurface.contents, surface.SDL_Surface)
         surface.SDL_FreeSurface(imgsurface)
         imgrw.close(imgrw)
 
-#        self.assertRaises(TypeError, surface.load_bmp_rw, "Test")
-#        self.assertRaises(TypeError, surface.load_bmp_rw, None)
-#        self.assertRaises(TypeError, surface.load_bmp_rw, 1234)
-
     def test_SDL_LoadBMP(self):
         imgsurface = surface.SDL_LoadBMP(self.testfile.encode("utf-8"))
-        self.assertIsInstance(imgsurface.contents, surface.SDL_Surface)
+        assert isinstance(imgsurface.contents, surface.SDL_Surface)
         surface.SDL_FreeSurface(imgsurface)
 
-#        self.assertRaises(sdl.SDLError, surface.load_bmp, "invalid path")
-#        self.assertRaises(sdl.SDLError, surface.load_bmp, None)
-#        self.assertRaises(sdl.SDLError, surface.load_bmp, 1234)
-
-    @unittest.skip("not implemented")
+    @pytest.mark.skip("not implemented")
     def test_SDL_SaveBMP_RW(self):
         pass
 
-    @unittest.skip("not implemented")
+    @pytest.mark.skip("not implemented")
     def test_SDL_SaveBMP(self):
         pass
 
+    @pytest.mark.skip("not implemented")
+    def test_SDL_GetSetYUVConversionMode(self):
+        pass
 
-if __name__ == '__main__':
-    sys.exit(unittest.main())
+    @pytest.mark.skip("not implemented")
+    def test_SDL_GetYUVConversionModeForResolution(self):
+        pass
