@@ -2,11 +2,21 @@ from ctypes import Structure, POINTER, c_char_p, c_int
 from .dll import _bind
 from .stdinc import Uint8
 
-__all__ = ["SDL_version", "SDL_MAJOR_VERSION", "SDL_MINOR_VERSION",
-           "SDL_PATCHLEVEL", "SDL_VERSION", "SDL_VERSIONNUM",
-           "SDL_COMPILEDVERSION", "SDL_VERSION_ATLEAST", "SDL_GetVersion",
-           "SDL_GetRevision", "SDL_GetRevisionNumber"
-           ]
+__all__ = [
+    # Structs
+    "SDL_version",
+
+    # Defines
+    "SDL_MAJOR_VERSION", "SDL_MINOR_VERSION", "SDL_PATCHLEVEL",
+
+    # Macro Functions
+    "SDL_VERSION", "SDL_VERSIONNUM", "SDL_COMPILEDVERSION",
+    "SDL_VERSION_ATLEAST",
+
+    # Functions
+    "SDL_GetVersion", "SDL_GetRevision", "SDL_GetRevisionNumber"
+]
+
 
 class SDL_version(Structure):
     _fields_ = [("major", Uint8),
@@ -16,7 +26,7 @@ class SDL_version(Structure):
 
 SDL_MAJOR_VERSION = 2
 SDL_MINOR_VERSION = 0
-SDL_PATCHLEVEL = 5
+SDL_PATCHLEVEL = 14
 
 def SDL_VERSION(x):
     x.major = SDL_MAJOR_VERSION
